| Title: | A simple modern interface to the standard streams |
|---|---|
| Description: | This package provides wrappers around different {cli} functions to easily work with simple in- and output from/to the standard streams. |
| Authors: | Bart Rogiers [cre, aut] (ORCID: <https://orcid.org/0000-0002-8836-0988>, url: <https://rogiersbart.github.io>), SCK CEN [cph, fnd] |
| Maintainer: | Bart Rogiers <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-31 08:59:53 UTC |
| Source: | https://github.com/rogiersbart/std |
This function provides an alternative to the verb-based API, by mapping the set of prefixes to the corresponding verbs.
err(...)err(...)
... |
Character vectors supporting glue strings and cli inline
styles. This should start with a supported prefix, to map the action to one
of the rui verbs. Otherwise, (give), * (suggest), ? (ask), ! (alert), w (warn), e (stop), . (display), and $ (expose). Status bars can be resolved by providing single characters "c", "v", or "x" for clear, succeed and fail respectively. |